@@ -2,9 +2,9 @@ from . import auth as syn
 
 
 class Core(object):
-    def __init__(self, ip_address, port, username, password, secure=False, cert_verify=False):
+    def __init__(self, ip_address, port, username, password, secure=False, cert_verify=False, dsm_version=2):
 
-        self.session = syn.Authentication(ip_address, port, username, password, secure, cert_verify)
+        self.session = syn.Authentication(ip_address, port, username, password, secure, cert_verify, dsm_version)
 
         self.session.login('Core')
         self.session.get_api_list('Core')
