@@ -11,9 +11,9 @@ from . import auth as syn
 
 class FileStation:
 
-    def __init__(self, ip_address, port, username, password, secure=False, cert_verify=False):
+    def __init__(self, ip_address, port, username, password, secure=False, cert_verify=False, dsm_version=2):
 
-        self.session = syn.Authentication(ip_address, port, username, password, secure, cert_verify)
+        self.session = syn.Authentication(ip_address, port, username, password, secure, cert_verify, dsm_version)
 
         self._dir_taskid = ''
         self._dir_taskid_list = []
@@ -406,9 +406,7 @@ class FileStation:
         req_param = {'version': info['maxVersion'], 'method': 'status', 'taskid': taskid}
 
         if taskid is None and self._dir_taskid is not '':
-            req_param['taskid'] = self._dir_taskid
-        else:
-            return 'Did you run start_dir_size_calc() first? No task id found!' + str(self._dir_taskid_list)
+            return 'Choose a taskid from this list: ' + str(self._dir_taskid)
 
         return self.request_data(api_name, api_path, req_param)
 
